# mutwo.common

[![Build Status](https://circleci.com/gh/mutwo-org/mutwo.common.svg?style=shield)](https://circleci.com/gh/mutwo-org/mutwo.common)
[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
[![PyPI version](https://badge.fury.io/py/mutwo.common.svg)](https://badge.fury.io/py/mutwo.common)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

Generators extension for event based library [mutwo](https://github.com/mutwo-org/mutwo.core).

This extension implements:

- `mutwo.common_generators`

### Installation

mutwo.common is available on [pypi](https://pypi.org/project/mutwo.common/) and can be installed via pip:

```sh
pip3 install mutwo.common
```
